pub struct InvalidProxyConfig(pub String);Expand description
InvalidProxyConfig
Error type for invalid proxy configurations.
This error is returned when a proxy configuration is deemed invalid, such as when required fields are missing or values are not in the expected format.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for InvalidProxyConfig
impl Debug for InvalidProxyConfig
Sourceimpl Display for InvalidProxyConfig
impl Display for InvalidProxyConfig
Sourceimpl Error for InvalidProxyConfig
impl Error for InvalidProxyConfig
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()